---
name: Feature Request
about: Suggest an idea or improvement for this project
title: 'feat: '
labels: enhancement
assignees: ''

---

## What?
- [ ] feature description


## Why? (want to avoid scope creep)
- [ ] benefit?


## How? (Rough Planning) # optional
- [ ] potential changes: `file1, file2`
- [ ] external dependencies? Yes/No
- [ ] steps
  1.
  2.
